@@ -25,10 +25,10 @@ class faker():
 
 if __name__ == '__main__':
     host = '192.168.84.26'
-    port = '30006'
+    key1 = 's_id'
+    port = 30006
     user = 'root'
     password = 'eisoo.com'
     database = 'AnyRobot'
-    key1 = 'tagID'
     date1 = faker(host,port,user,password,database).route(key1)
     print(date1)
\ No newline at end of file
