@@ -33,7 +33,10 @@ def sql(key):
         'tagID': {'sql': "SELECT id From Tag;", 'database': 'AnyRobot'},
         'HostID': {'sql': "SELECT ip From AgentHost;", 'database': 'AnyRobot'},
         'openapiID': {'sql': "SELECT id From OpenAPIManager;", 'database': 'AnyRobotOpenLog'},
-        'UserID_Notadmin': {'sql': 'select userId from User where loginName != "admin";', 'database': 'AnyRobot'}
+        'UserID_Notadmin': {'sql': 'select userId from User where loginName != "admin";', 'database': 'AnyRobot'},
+        'mysqlJdbcID': {'sql': "select collectorId from JDBCCollectorConfig where JDBCCollectorConfig.type='mysqljdbc' AND JDBCCollectorConfig.`sql`='select * from AgentHost';",'database': 'AnyRobot'},
+        'vSphereID': {'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='vSphere' AND config LIKE '%192.168.0.250%';",'database': 'AnyRobot'},
+        'vCenterID': {'sql': "SELECT collectorId FROM CollectorConfig WHERE collectorType='vCenter' AND config LIKE '%192.168.0.250%';",'database': 'AnyRobot'}
     }
 
     if switcher.get(key) is not None:
