@@ -69,7 +69,9 @@ def filed(key,inquire=[]):
         'UpdateTimeID': ParaDateFiledServer().getUpdateTime,
         'UtcStartID': ParaDateFiledServer().getUtcStartTime,
         'UtcEndID': ParaDateFiledServer().getUtcEndTime,
-        's_id': zx.search().createSearchId
+        's_id': zx.search().createSearchId,
+        'InspectionID': zx.search().createInspectionID,
+        'InspectionTaskID': zx.search().createInspectionTaskID
     }
 
     switcher = SERVICE_KPI_
